View source: R/constructJUnitTag.R
| constructTestsuiteTag | R Documentation |
</testsuite> tagConstruct the </testsuite> tag of a tinytest, given all the tinytest results
from a single test file.
constructTestsuiteTag(testsFile, id)
testsFile |
|
id |
|
In case a tinytest2JUnit is provided following additional info can be reported:
testsuite duration.
timestamp when the testsuite was performed.
hostname where the testsuite was ran.
XMLtag: with tag-name = </testsuite>
that contains all the test results per test file.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.